@@ -84,12 +84,14 @@ struct FS
 	enum Support
 	{
 		NONE		= 0,
-		LIBPARTED	= 1,
-		EXTERNAL	= 2
+		GPARTED		= 1,
+		LIBPARTED	= 2,
+		EXTERNAL	= 3
 	};
 
 	FILESYSTEM filesystem ;
 	Support read ; //can we get the amount of used sectors?
+	Support get_label ;
 	Support create ;
 	Support grow ;
 	Support shrink ;
@@ -102,7 +104,7 @@ struct FS
 	
 	FS()
 	{
-		read = create = grow = shrink = move = check = copy = NONE;
+		read = get_label = create = grow = shrink = move = check = copy = NONE;
 		MIN = MAX = 0 ;
 	} 
 } ;
@@ -123,6 +125,7 @@ public:
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FILESYSTEM filesystem, int width, int height ) ;
 	static Glib::ustring get_filesystem_string( FILESYSTEM filesystem ) ;
 	static Glib::ustring format_size( Sector size ) ;
+	static Glib::ustring format_time( std::time_t seconds ) ;
 	static double sector_to_unit( Sector sectors, SIZE_UNIT size_unit ) ;
 	static int execute_command( const Glib::ustring & command ) ;
 	static int execute_command( const Glib::ustring & command,
