@@ -25,15 +25,13 @@ OperationCopy::OperationCopy( const Device & device,
 			      const Partition & partition_new,
 			      const Partition & partition_copied )
 {
-	type = GParted::COPY ;
+	type = OPERATION_COPY ;
 
 	this ->device = device ;
 	this ->partition_original = partition_orig ;
 	this ->partition_new = partition_new ;
 	this ->partition_copied = partition_copied ;
 
-	create_description() ;
-	
 	this ->partition_new .add_path(  
 		String::ucompose( _("copy of %1"), this ->partition_copied .get_path() ), true ) ;
 }
@@ -89,7 +87,6 @@ void OperationCopy::create_description()
 					        partition_copied .get_path(),
 						partition_original .get_path() ) ;
 	}
-
 }
 
 } //GParted
