@@ -21,7 +21,7 @@
 namespace GParted
 {
 
-FS hfsplus::get_filesystem_support( )
+FS hfsplus::get_filesystem_support()
 {
 	FS fs ;
 	
@@ -30,49 +30,38 @@ FS hfsplus::get_filesystem_support( )
 	fs .read = GParted::FS::LIBPARTED ; 
 	fs .shrink = GParted::FS::LIBPARTED ; 
 	
-	if ( ! Glib::find_program_in_path( "dd" ) .empty() )
-		fs .copy = GParted::FS::EXTERNAL ;
+	fs .copy = GParted::FS::GPARTED ;
+	fs .move = GParted::FS::GPARTED ;
 	
 	return fs ;
 }
 
-void hfsplus::Set_Used_Sectors( Partition & partition ) 
+void hfsplus::set_used_sectors( Partition & partition ) 
 {
 }
 
-bool hfsplus::Create( const Partition & new_partition, std::vector<OperationDetails> & operation_details )
+void hfsplus::get_label( Partition & partition )
+{
+}
+
+bool hfsplus::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	return true ;
 }
 
-bool hfsplus::Resize( const Partition & partition_new, 
-		      std::vector<OperationDetails> & operation_details,
-		      bool fill_partition )
+bool hfsplus::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	return true ;
 }
 
-bool hfsplus::Copy( const Glib::ustring & src_part_path,
+bool hfsplus::copy( const Glib::ustring & src_part_path,
 		    const Glib::ustring & dest_part_path,
-		    std::vector<OperationDetails> & operation_details )
+		    OperationDetail & operationdetail )
 {
-	operation_details .push_back( OperationDetails( 
-				String::ucompose( _("copy contents of %1 to %2"), src_part_path, dest_part_path ) ) ) ;
-
-	if ( ! execute_command( "dd bs=8192 if=" + src_part_path + " of=" + dest_part_path,
-				 operation_details .back() .sub_details ) )
-	{
-		operation_details .back() .status = OperationDetails::SUCCES ;
-		return true ;	
-	}
-	else
-	{
-		operation_details .back() .status = OperationDetails::ERROR ;
-		return false ;
-	}
+	return true ;
 }
 
-bool hfsplus::Check_Repair( const Partition & partition, std::vector<OperationDetails> & operation_details )
+bool hfsplus::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
 	return true ;
 }
